if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi
( cd usr/lib64 ; rm -rf libfolks-dummy.so )
( cd usr/lib64 ; ln -sf libfolks-dummy.so.26 libfolks-dummy.so )
( cd usr/lib64 ; rm -rf libfolks-dummy.so.26 )
( cd usr/lib64 ; ln -sf libfolks-dummy.so.26.0.0 libfolks-dummy.so.26 )
( cd usr/lib64 ; rm -rf libfolks-eds.so )
( cd usr/lib64 ; ln -sf libfolks-eds.so.26 libfolks-eds.so )
( cd usr/lib64 ; rm -rf libfolks-eds.so.26 )
( cd usr/lib64 ; ln -sf libfolks-eds.so.26.0.0 libfolks-eds.so.26 )
( cd usr/lib64 ; rm -rf libfolks-telepathy.so )
( cd usr/lib64 ; ln -sf libfolks-telepathy.so.26 libfolks-telepathy.so )
( cd usr/lib64 ; rm -rf libfolks-telepathy.so.26 )
( cd usr/lib64 ; ln -sf libfolks-telepathy.so.26.0.0 libfolks-telepathy.so.26 )
( cd usr/lib64 ; rm -rf libfolks.so )
( cd usr/lib64 ; ln -sf libfolks.so.26 libfolks.so )
( cd usr/lib64 ; rm -rf libfolks.so.26 )
( cd usr/lib64 ; ln -sf libfolks.so.26.0.0 libfolks.so.26 )
